@@ -8,7 +8,6 @@ Copyright (C) 2005-2019 Splunk Inc. All Rights Reserved.
 Commonly used design partten for python user, includes:
   - singleton (Decorator function used to build singleton)
 """
-from __future__ import print_function
 
 from functools import wraps
 
@@ -37,6 +36,6 @@ class Singleton(type):
 
     def __call__(cls, *args, **kwargs):
         if cls not in cls._instances:
-            cls._instances[cls] = super(Singleton, cls).__call__(*args, **kwargs)
+            cls._instances[cls] = super().__call__(*args, **kwargs)
             print(cls)
         return cls._instances[cls]
